@@ -39,7 +39,6 @@ enum {
 	PROP_CURRENT_COLOR,
 	PROP_DEFAULT_COLOR,
 	PROP_DEFAULT_LABEL,
-	PROP_DEFAULT_TRANSPARENT,
 	PROP_PALETTE,
 	PROP_POPUP_SHOWN,
 	PROP_STATE
@@ -129,12 +128,8 @@ color_combo_notify_current_color_cb (GtkhtmlColorCombo *combo)
 	GdkColor color;
 
 	swatch = GTKHTML_COLOR_SWATCH (combo->priv->swatch);
-	if (gtkhtml_color_combo_get_current_color (combo, &color))
-		gtkhtml_color_swatch_set_color (swatch, &color);
-	else if (gtkhtml_color_combo_get_default_transparent (combo))
-		gtkhtml_color_swatch_set_color (swatch, NULL);
-	else
-		gtkhtml_color_swatch_set_color (swatch, &color);
+	gtkhtml_color_combo_get_current_color (combo, &color);
+	gtkhtml_color_swatch_set_color (swatch, &color);
 
 	g_signal_emit (G_OBJECT (combo), signals[CHANGED], 0);
 }
@@ -152,26 +147,23 @@ color_combo_reposition_window (GtkhtmlColorCombo *combo)
 	GdkScreen *screen;
 	GdkWindow *window;
 	GdkRectangle monitor;
-	GtkAllocation allocation;
 	gint monitor_num;
 	gint x, y, width, height;
 
+	window = GTK_WIDGET (combo)->window;
 	screen = gtk_widget_get_screen (GTK_WIDGET (combo));
-	window = gtk_widget_get_window (GTK_WIDGET (combo));
 	monitor_num = gdk_screen_get_monitor_at_window (screen, window);
 	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
 	gdk_window_get_origin (window, &x, &y);
 
-	if (!gtk_widget_get_has_window (GTK_WIDGET (combo))) {
-		gtk_widget_get_allocation (GTK_WIDGET (combo), &allocation);
-		x += allocation.x;
-		y += allocation.y;
+	if (GTK_WIDGET_NO_WINDOW (combo)) {
+		x += GTK_WIDGET (combo)->allocation.x;
+		y += GTK_WIDGET (combo)->allocation.y;
 	}
 
-	gtk_widget_get_allocation (combo->priv->window, &allocation);
-	width = allocation.width;
-	height = allocation.height;
+	width = combo->priv->window->allocation.width;
+	height = combo->priv->window->allocation.height;
 
 	x = CLAMP (x, monitor.x, monitor.x + monitor.width - width);
 	y = CLAMP (y, monitor.y, monitor.y + monitor.height - height);
@@ -275,11 +267,10 @@ color_combo_custom_clicked_cb (GtkhtmlColorCombo *combo)
 	gtkhtml_color_combo_popdown (combo);
 
 	dialog = gtk_color_selection_dialog_new (_("Choose Custom Color"));
-	colorsel = gtk_color_selection_dialog_get_color_selection (
-		GTK_COLOR_SELECTION_DIALOG (dialog));
+	colorsel = GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel;
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (combo));
 
-	if (gtk_widget_is_toplevel (toplevel))
+	if (GTK_WIDGET_TOPLEVEL (toplevel))
 		gtk_window_set_transient_for (
 			GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
 
@@ -321,11 +312,7 @@ color_combo_default_release_event_cb (GtkhtmlColorCombo *combo,
                                       GdkEventButton *event,
                                       GtkButton *button)
 {
-	GtkStateType state;
-
-	state = gtk_widget_get_state (GTK_WIDGET (button));
-
-	if (state != GTK_STATE_NORMAL)
+	if (GTK_WIDGET_STATE (button) != GTK_STATE_NORMAL)
 		gtk_button_clicked (button);
 
 	return FALSE;
@@ -378,15 +365,12 @@ color_combo_swatch_release_event_cb (GtkhtmlColorCombo *combo,
                                      GdkEventButton *event,
                                      GtkButton *button)
 {
-	GtkStateType state;
-
-	state = gtk_widget_get_state (GTK_WIDGET (button));
-
-	if (state != GTK_STATE_NORMAL)
+	if (GTK_WIDGET_STATE (button) != GTK_STATE_NORMAL)
 		gtk_button_clicked (button);
 
 	return FALSE;
 }
+                                     
 
 static void
 color_combo_toggled_cb (GtkhtmlColorCombo *combo)
@@ -459,12 +443,6 @@ color_combo_set_property (GObject *object,
 				g_value_get_string (value));
 			return;
 
-		case PROP_DEFAULT_TRANSPARENT:
-			gtkhtml_color_combo_set_default_transparent (
-				GTKHTML_COLOR_COMBO (object),
-				g_value_get_boolean (value));
-			return;
-
 		case PROP_PALETTE:
 			gtkhtml_color_combo_set_palette (
 				GTKHTML_COLOR_COMBO (object),
@@ -520,13 +498,6 @@ color_combo_get_property (GObject *object,
 				GTKHTML_COLOR_COMBO (object)));
 			return;
 
-		case PROP_DEFAULT_TRANSPARENT:
-			g_value_set_boolean (
-				value,
-				gtkhtml_color_combo_get_default_transparent (
-				GTKHTML_COLOR_COMBO (object)));
-			return;
-
 		case PROP_PALETTE:
 			g_value_set_object (
 				value, gtkhtml_color_combo_get_palette (
@@ -618,7 +589,7 @@ color_combo_size_allocate (GtkWidget *widget,
 
 	priv = GTKHTML_COLOR_COMBO_GET_PRIVATE (widget);
 
-	gtk_widget_set_allocation (widget, allocation);
+	widget->allocation = *allocation;
 	gtk_widget_size_allocate (priv->toggle_button, allocation);
 }
 
@@ -631,7 +602,7 @@ color_combo_popup (GtkhtmlColorCombo *combo)
 	GdkGrabStatus status;
 	const gchar *label;
 
-	if (!gtk_widget_get_realized (GTK_WIDGET (combo)))
+	if (!GTK_WIDGET_REALIZED (combo))
 		return;
 
 	if (combo->priv->popup_shown)
@@ -654,7 +625,7 @@ color_combo_popup (GtkhtmlColorCombo *combo)
 	gtk_toggle_button_set_active (toggle_button, TRUE);
 
 	/* Try to grab the pointer and keyboard. */
-	window = gtk_widget_get_window (combo->priv->window);
+	window = combo->priv->window->window;
 	status = gdk_pointer_grab (
 		window, TRUE,
 		GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
@@ -678,7 +649,7 @@ color_combo_popdown (GtkhtmlColorCombo *combo)
 {
 	GtkToggleButton *toggle_button;
 
-	if (!gtk_widget_get_realized (GTK_WIDGET (combo)))
+	if (!GTK_WIDGET_REALIZED (combo))
 		return;
 
 	if (!combo->priv->popup_shown)
@@ -719,8 +690,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_CURRENT_COLOR,
 		g_param_spec_boxed (
 			"current-color",
-			"Current color",
-			"The currently selected color",
+			_("Current color"),
+			_("The currently selected color"),
 			GDK_TYPE_COLOR,
 			G_PARAM_READWRITE));
 
@@ -729,8 +700,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_DEFAULT_COLOR,
 		g_param_spec_boxed (
 			"default-color",
-			"Default color",
-			"The color associated with the default button",
+			_("Default color"),
+			_("The color associated with the default button"),
 			GDK_TYPE_COLOR,
 			G_PARAM_CONSTRUCT |
 			G_PARAM_READWRITE));
@@ -740,30 +711,19 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_DEFAULT_LABEL,
 		g_param_spec_string (
 			"default-label",
-			"Default label",
-			"The label for the default button",
+			_("Default label"),
+			_("The label for the default button"),
 			_("Default"),
 			G_PARAM_CONSTRUCT |
 			G_PARAM_READWRITE));
 
-	g_object_class_install_property (
-		object_class,
-		PROP_DEFAULT_TRANSPARENT,
-		g_param_spec_boolean (
-			"default-transparent",
-			"Default is transparent",
-			"Whether the default color is transparent",
-			FALSE,
-			G_PARAM_CONSTRUCT |
-			G_PARAM_READWRITE));
-
 	g_object_class_install_property (
 		object_class,
 		PROP_PALETTE,
 		g_param_spec_object (
 			"palette",
-			"Color palette",
-			"Custom color palette",
+			_("Color palette"),
+			_("Custom color palette"),
 			GTKHTML_TYPE_COLOR_PALETTE,
 			G_PARAM_READWRITE));
 
@@ -772,8 +732,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_POPUP_SHOWN,
 		g_param_spec_boolean (
 			"popup-shown",
-			"Popup shown",
-			"Whether the combo's dropdown is shown",
+			_("Popup shown"),
+			_("Whether the combo's dropdown is shown"),
 			FALSE,
 			G_PARAM_READWRITE));
 
@@ -782,8 +742,8 @@ color_combo_class_init (GtkhtmlColorComboClass *class)
 		PROP_STATE,
 		g_param_spec_object (
 			"state",
-			"Color state",
-			"The state of a color combo box",
+			_("Color state"),
+			_("State of the color combo"),
 			GTKHTML_TYPE_COLOR_STATE,
 			G_PARAM_READWRITE));
 
@@ -888,11 +848,11 @@ color_combo_init (GtkhtmlColorCombo *combo)
 	/* Build the pop-up window. */
 
 	window = gtk_window_new (GTK_WINDOW_POPUP);
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (combo));
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (combo));	
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
 	gtk_window_set_type_hint (
 		GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_COMBO);
-	if (gtk_widget_is_toplevel (toplevel)) {
+	if (GTK_WIDGET_TOPLEVEL (toplevel)) {
 		gtk_window_group_add_window (
 			gtk_window_get_group (GTK_WINDOW (toplevel)),
 			GTK_WINDOW (window));
@@ -1107,24 +1067,6 @@ gtkhtml_color_combo_set_default_label (GtkhtmlColorCombo *combo,
 	gtkhtml_color_state_set_default_label (combo->priv->state, text);
 }
 
-gboolean
-gtkhtml_color_combo_get_default_transparent (GtkhtmlColorCombo *combo)
-{
-	g_return_val_if_fail (GTKHTML_IS_COLOR_COMBO (combo), FALSE);
-
-	return gtkhtml_color_state_get_default_transparent (combo->priv->state);
-}
-
-void
-gtkhtml_color_combo_set_default_transparent (GtkhtmlColorCombo *combo,
-                                             gboolean transparent)
-{
-	g_return_if_fail (GTKHTML_IS_COLOR_COMBO (combo));
-
-	gtkhtml_color_state_set_default_transparent (
-		combo->priv->state, transparent);
-}
-
 GtkhtmlColorPalette *
 gtkhtml_color_combo_get_palette (GtkhtmlColorCombo *combo)
 {
